# Standalone Kernel Evaluation
# 45_Average_Pooling_2D
This directory contains everything needed to evaluate a CUDA kernel's correctness and performance.

## Kernel Information
- Level: 1
- Task ID: 45
- Kernel Path: /tmp/standalone_eval_cwed40v3/level_1_task_45_eval/kernel/kernel.cu

## Structure
- kernel/: Contains the CUDA kernel implementation
- task/: Contains the PyTorch task definition and reference implementation
- eval_kernel.py: Script to test and evaluate the kernel

## Task Description
The task information can be found in the task directory. The implementation:
1. Uses a PyTorch model class with custom forward function
2. Compares CUDA kernel output against PyTorch reference implementation
3. Measures performance of both implementations

## Usage
Test kernel correctness and evaluate performance (includes PyTorch baseline):
```bash
python eval_kernel.py
```

Additional options:
- --op_atol: Absolute tolerance for correctness testing (default: 1e-3)
- --op_rtol: Relative tolerance for correctness testing (default: 1e-1)
- --rep_time: Number of repetitions for performance evaluation (default: 10000)
- --warmup_time: Number of warmup iterations (default: 25)

## Evaluation Process
1. Correctness Testing:
   - Compares CUDA kernel output against PyTorch reference
   - Reports if outputs match within tolerance
   - Shows maximum difference between outputs

2. Performance Evaluation:
   - Measures PyTorch baseline runtime
   - Measures CUDA kernel runtime
   - Reports speedup over PyTorch implementation

## Build Information
- CUDA compilation flags: -O3 --use_fast_math
- PyTorch extension build: JIT compilation using torch.utils.cpp_extension
- Kernel loaded as: module.forward function

## Directory Creation Date
2025-02-22 22:21:25
